Contributing to Eliot
^^^^^^^^^^^^^^^^^^^^^

To run the full test suite, the Daemontools package should be installed.

All modules should have the ``from __future__ import unicode_literals`` statement, to ensure Unicode is used by default.

Coding standard is `Twisted's`_, but you should also expose PEP 8 compatible method names for use by non-Twisted projects.

.. _Twisted's: https://twistedmatrix.com/documents/current/core/development/policy/coding-standard.html
